package MT::Plugin::SKR::DevHelperLinkChecker;
# @see http://www.skyarc.co.jp/engineerblog/entry/devhelperlinkchecker.html

use strict;
use MT 3;

use vars qw( $MYNAME $VERSION );
$MYNAME = 'DevHelperLinkChecker';
$VERSION = '0.01';

use base qw( MT::Plugin );
my $plugin = __PACKAGE__->new({
    name => $MYNAME,
    id => lc $MYNAME,
    key => lc $MYNAME,
    version => $VERSION,
    author_name => 'SKYARC System Co.,Ltd.',
    author_link => 'http://www.skyarc.co.jp/',
    doc_link => 'http://www.skyarc.co.jp/engineerblog/entry/devhelperlinkchecker.html',
    description => <<HTMLHEREDOC,
<__trans phrase="Check whether some links for development environment are remained.">
HTMLHEREDOC
    system_config_template => \&_hdlr_config,
    settings => new MT::PluginSettings([
        ['url', { Default => 'http://dev.example.com/', Scope => 'system' }],
    ]),
});
MT->add_plugin ($plugin);

sub instance { $plugin; }

### Configuration screen
sub _hdlr_config {
    return <<'HTMLHEREDOC';
<mtapp:setting
    id="url"
    label="<__trans phrase="URL">">
<textarea name="url"><TMPL_VAR NAME=URL ESCAPE=HTML></textarea>
</mtapp:setting>
HTMLHEREDOC
}



### Registry
sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'BuildFile' => \&_hdlr_build_file_filter,
        },
    });
}

### BuildFile
sub _hdlr_build_file_filter {
    my ($cb, %opt) = @_;
    my $content = ${$opt{'Content'}};
    my $blog = $opt{'Blog'};
    my $tmpl = $opt{'Template'};

    my $config = $plugin->get_config_value ('url', 'system')
        or return undef; # not yet configured
    my $urls = join ('|', grep { length $_ } split (/\s+/, $config));
    while ($content =~ s/($urls)//) {
        MT->log({
            message => "Illegal link $1 found in ". $tmpl->name,
            blog_id => $blog->id,
        });
    }
}

1;
__END__